@@ -58,6 +58,7 @@ sub get {
 					back_color => '000022',
 					font_size => 9,
 					fore_color => 'ffffff',
+					interpreter_path => 'perl',
 					size => 100,
 					visible => 0,
 				},
@@ -168,6 +169,7 @@ sub get {
 			},
 			indicator => {
 				bracelight => {
+					back_color => '99ff99',
 					bad_color  => 'ff0000',
 					good_color => '0000ff',
 					mode       => 'adjacent',
